@@ -2,7 +2,7 @@
  * Album (Buddy Icon Archiver)
  *
  * Copyright (C) 2005-2006, Sadrul Habib Chowdhury <imadil@gmail.com>
- * Copyright (C) 2005-2006, Richard Laager <rlaager@users.sf.net>
+ * Copyright (C) 2005-2006, Richard Laager <rlaager@pidgin.im>
  * Copyright (C) 2006, Jérôme Poulin (TiCPU) <jeromepoulin@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -17,14 +17,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02111-1301, USA.
  */
 
 #include "album-ui.h"
 
-#include <glib.h>
-
 /* We want to use the gstdio functions when possible so that non-ASCII
  * filenames are handled properly on Windows. */
 #if GLIB_CHECK_VERSION(2,6,0)
@@ -48,7 +46,6 @@
 #include <plugin.h>
 #include <request.h>
 #include <util.h>
-#include <version.h>
 
 /* XXX: For DATADIR... There must be a better way. */
 #ifdef _WIN32
