@@ -1,7 +1,7 @@
 /*
  * IRC Helper Plugin for libpurple
  *
- * Copyright (C) 2005-2007, Richard Laager <rlaager@users.sf.net>
+ * Copyright (C) 2005-2007, Richard Laager <rlaager@pidgin.im>
  * Copyright (C) 2004-2005, Mathias Hasselmann <mathias@taschenorakel.de>
  * Copyright (C) 2005, Daniel Beardsmore <uilleann@users.sf.net>
  * Copyright (C) 2005, Björn Nilsson <BNI on irc.freenode.net>
@@ -19,18 +19,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02111-1301, USA.
  */
 
-#include <glib.h>
+#include "../common/pp_internal.h"
 
 #include <string.h>
 
-#ifndef PURPLE_PLUGINS
-#define PURPLE_PLUGINS
-#endif
-
 #include <account.h>
 #include <accountopt.h>
 #include <cmds.h>
@@ -42,17 +38,10 @@
 #include <pluginpref.h>
 #include <prefs.h>
 #include <util.h>
-#include <version.h>
-
-#include "../common/pp_internal.h"
 
 #define PLUGIN_STATIC_NAME "irchelper"
 #define PLUGIN_ID "core-rlaager-" PLUGIN_STATIC_NAME
 
-#define PLUGIN_NAME        "IRC Helper"
-#define PLUGIN_SUMMARY     "Handles the rough edges of the IRC protocol."
-#define PLUGIN_DESCRIPTION "- Transparent authentication with a variety of services.\n" \
-                           "- Suppression of various useless messages"
 #define PLUGIN_AUTHOR      "Richard Laager <rlaager@guifications.org>"
 
 
@@ -1269,9 +1258,10 @@ static void plugin_init(PurplePlugin *plugin)
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 #endif /* ENABLE_NLS */
 
-	info.name = _(PLUGIN_NAME);
-	info.summary = _(PLUGIN_SUMMARY);
-	info.description = _(PLUGIN_DESCRIPTION);
+	info.name = _("IRC Helper");
+	info.summary = _("Handles the rough edges of the IRC protocol.");
+	info.description = _("- Transparent authentication with a variety of "
+			"services.\n- Suppression of various useless messages");
 }
 
 PURPLE_INIT_PLUGIN(PLUGIN_STATIC_NAME, plugin_init, info)
