@@ -18,17 +18,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1301, USA.
  */
+
 #ifndef _LISTHANDLER_GEN_XML_H
 #define _LISTHANDLER_GEN_XML_H
 
 void lh_generic_import_action_cb(PurplePluginAction *action);
 void lh_generic_export_action_cb(PurplePluginAction *action);
 
-void lh_generic_import_alist_action_cb(PurplePluginAction *action);
-void lh_generic_export_alist_action_cb(PurplePluginAction *action);
-
-
-
 #endif /*_LISTHANDLER_GEN_XML_H*/
