@@ -18,30 +18,21 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1301, USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#	include "../pp_config.h"
-#endif
+#include "../common/pp_internal.h"
 
-#include <glib.h>
 #include <string.h>
 
-/* this has to be defined for the plugin to work properly */
-#define PURPLE_PLUGINS
-
 /* Purple headers */
 #include <account.h>
 #include <blist.h>
 #include <debug.h>
 #include <plugin.h>
 #include <request.h>
-#include <version.h>
 #include <xmlnode.h>
 
-#include "../common/pp_internal.h"
-
 #include "lh_util.h"
 
 /* we send this to the request API so it is probably a good idea to make sure
