@@ -14,36 +14,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02111-1301, USA.
  */
-#ifdef HAVE_CONFIG_H
-# include "../pp_config.h"
-#endif
 
-#define PURPLE_PLUGINS
+#include "../common/pp_internal.h"
 
 #define PLUGIN_ID			"gtk-plugin_pack-mystatusbox"
-#define PLUGIN_NAME			"Mystatusbox (Show Statusboxes)"
 #define PLUGIN_STATIC_NAME	"mystatusbox"
-#define PLUGIN_SUMMARY		"Hide/Show the per-account statusboxes"
-#define PLUGIN_DESCRIPTION	"You can show all the per-account statusboxes, " \
-							"hide all of them, or just show the ones that are " \
-							"in a different status than the global status.\n\n" \
-							"For ease of use, you can bind keyboard-shortcuts " \
-							"for the menu-items."
 #define PLUGIN_AUTHOR		"Sadrul Habib Chowdhury <sadrul@users.sourceforge.net>"
 
 /* System headers */
 #include <gdk/gdk.h>
-#include <glib.h>
 #include <gtk/gtk.h>
 
-/* Purple headers */
-#include <version.h>
-
-#if PURPLE_VERSION_CHECK(2,0,0) /* Stu is a chicken */
-
 #include <core.h>
 
 #include <gtkblist.h>
@@ -51,9 +35,6 @@
 #include <gtkplugin.h>
 #include <gtkstatusbox.h>
 
-/* Pack/Local headers */
-#include "../common/pp_internal.h"
-
 /* XXX: THIS NEEDS CHANGED WHEN PIDGIN DOES ITS PREFS MIGRATION!!!!! */
 #define PREF_PREFIX "/plugins/gtk/" PLUGIN_ID
 #define PREF_PANE	PREF_PREFIX "/pane"
@@ -560,6 +541,7 @@ static PurplePluginInfo info =
 	NULL,							/* extra_info			*/
 	&prefs_info,					/* prefs_info			*/
 	actions,						/* actions				*/
+
 	NULL,							/* reserved 1			*/
 	NULL,							/* reserved 2			*/
 	NULL,							/* reserved 3			*/
@@ -573,9 +555,12 @@ init_plugin(PurplePlugin *plugin) {
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 #endif /* ENABLE_NLS */
 
-	info.name = _(PLUGIN_NAME);
-	info.summary = _(PLUGIN_SUMMARY);
-	info.description = _(PLUGIN_DESCRIPTION);
+	info.name = _("Mystatusbox (Show Statusboxes)");
+	info.summary = _("Hide/Show the per-account statusboxes");
+	info.description = _("You can show all the per-account statusboxes, hide "
+			"all of them, or just show the ones that are in a different status "
+			"from the global status.  For ease of use, you can bind keyboard "
+			"shortcuts for the menu items.");
 
 	purple_prefs_add_none(PREF_PREFIX);
 	purple_prefs_add_int(PREF_PANE, 300);
@@ -585,4 +570,4 @@ init_plugin(PurplePlugin *plugin) {
 }
 
 PURPLE_INIT_PLUGIN(PLUGIN_STATIC_NAME, init_plugin, info)
-#endif
+
