@@ -14,20 +14,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02111-1301, USA.
  */
-#ifdef HAVE_CONFIG_H
-# include "../pp_config.h"
-#endif
 
-#define PURPLE_PLUGINS
+#include "../common/pp_internal.h"
 
 #define PLUGIN_ID			"gtk-plugin_pack-nicksaid"
-#define PLUGIN_NAME			"Nicksaid"
-#define PLUGIN_STATIC_NAME	"Nicksaid"
-#define PLUGIN_SUMMARY		"Record when someone said your nick in a chat."
-#define PLUGIN_DESCRIPTION	"Record when someone said your nick in a chat."
+#define PLUGIN_STATIC_NAME	"nicksaid"
 #define PLUGIN_AUTHOR		"Sadrul H Chowdhury <sadrul@users.sourceforge.net>"
 
 #define PREF_PREFIX			"/plugins/gtk/" PLUGIN_ID
@@ -41,24 +35,18 @@
 /* System headers */
 #include <string.h>
 #include <gdk/gdk.h>
-#include <glib.h>
 #include <gtk/gtk.h>
 
-/* Purple headers */
-#include <gtkplugin.h>
-#include <version.h>
-
-#include <conversation.h>
+/* libpurple headers */
 #include <notify.h>
 
+/* Pidgin headers */
 #include <gtkconv.h>
 #include <gtkimhtml.h>
 #include <gtkmenutray.h>
-#include <pidginstock.h>
+#include <gtkplugin.h>
 #include <gtkutils.h>
-
-/* Pack/Local headers */
-#include "../common/pp_internal.h"
+#include <pidginstock.h>
 
 #define DELIMS " .,;|<>?/\\`~!@#$%^&*()_-+={}[]:'\""
 
@@ -659,9 +647,9 @@ init_plugin(PurplePlugin *plugin)
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 #endif /* ENABLE_NLS */
 
-	info.name = _(PLUGIN_NAME);
-	info.summary = _(PLUGIN_SUMMARY);
-	info.description = _(PLUGIN_DESCRIPTION);
+	info.name = _("Nicksaid");
+	info.summary = _("Record when someone said your nick in a chat.");
+	info.description = _("Record when someone said your nick in a chat.");
 
 	purple_prefs_add_none(PREF_PREFIX);
 	purple_prefs_add_string(PREF_HLWORDS, "");
