@@ -14,32 +14,23 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02111-1301, USA.
  */
-#ifdef HAVE_CONFIG_H
-# include "../pp_config.h"
-#endif
 
-#define PURPLE_PLUGINS
+#include "../common/pp_internal.h"
 
-#define PLUGIN_ID			"gtk-schedule"
-#define PLUGIN_NAME			"Purple Schedule"
-#define PLUGIN_STATIC_NAME	"Purple Schedule"
-#define PLUGIN_SUMMARY		"Schedule reminders at specified times."
-#define PLUGIN_DESCRIPTION	"Schedule reminders at specified times."
+#define PLUGIN_ID			"gtk-plugin_pack-schedule"
+#define PLUGIN_STATIC_NAME	"schedule"
 #define PLUGIN_AUTHOR		"Sadrul H Chowdhury <sadrul@users.sourceforge.net>"
 
 /* System headers */
 #include <gdk/gdk.h>
-#include <glib.h>
 #include <gtk/gtk.h>
 
-/* Purple headers */
-#include <gtkplugin.h>
-#include <version.h>
-
+/* Pidgin headers */
 #include <gtkimhtml.h>
+#include <gtkplugin.h>
 #include <gtkutils.h>
 
 #include "schedule.h"
@@ -714,9 +705,9 @@ init_plugin(PurplePlugin *plugin)
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 #endif /* ENABLE_NLS */
 
-	info.name = _(PLUGIN_NAME);
-	info.summary = _(PLUGIN_SUMMARY);
-	info.description = _(PLUGIN_DESCRIPTION);
+	info.name = _("Schedule");
+	info.summary = _("Schedule reminders at specified times.");
+	info.description = _("Schedule reminders at specified times.");
 }
 
 PURPLE_INIT_PLUGIN(PLUGIN_STATIC_NAME, init_plugin, info)
